@@ -15,6 +15,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import copy
 import math
 
 import mock
@@ -271,43 +272,43 @@ class MaskPasswordTestCase(test_base.BaseTestCase):
 
     def test_json(self):
         # Test 'adminPass' w/o spaces
-        payload = """{'adminPass':'mypassword'}"""
+        payload = """{'adminPass':'TL0EfN33'}"""
         expected = """{'adminPass':'***'}"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'adminPass' with spaces
-        payload = """{ 'adminPass' : 'mypassword' }"""
+        payload = """{ 'adminPass' : 'TL0EfN33' }"""
         expected = """{ 'adminPass' : '***' }"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'admin_pass' w/o spaces
-        payload = """{'admin_pass':'mypassword'}"""
+        payload = """{'admin_pass':'TL0EfN33'}"""
         expected = """{'admin_pass':'***'}"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'admin_pass' with spaces
-        payload = """{ 'admin_pass' : 'mypassword' }"""
+        payload = """{ 'admin_pass' : 'TL0EfN33' }"""
         expected = """{ 'admin_pass' : '***' }"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'admin_password' w/o spaces
-        payload = """{'admin_password':'mypassword'}"""
+        payload = """{'admin_password':'TL0EfN33'}"""
         expected = """{'admin_password':'***'}"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'admin_password' with spaces
-        payload = """{ 'admin_password' : 'mypassword' }"""
+        payload = """{ 'admin_password' : 'TL0EfN33' }"""
         expected = """{ 'admin_password' : '***' }"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'password' w/o spaces
-        payload = """{'password':'mypassword'}"""
+        payload = """{'password':'TL0EfN33'}"""
         expected = """{'password':'***'}"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'password' with spaces
-        payload = """{ 'password' : 'mypassword' }"""
+        payload = """{ 'password' : 'TL0EfN33' }"""
         expected = """{ 'password' : '***' }"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'auth_password' w/o spaces
-        payload = """{'auth_password':'mypassword'}"""
+        payload = """{'auth_password':'TL0EfN33'}"""
         expected = """{'auth_password':'***'}"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'auth_password' with spaces
-        payload = """{ 'auth_password' : 'mypassword' }"""
+        payload = """{ 'auth_password' : 'TL0EfN33' }"""
         expected = """{ 'auth_password' : '***' }"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'secret_uuid' w/o spaces
@@ -329,93 +330,93 @@ class MaskPasswordTestCase(test_base.BaseTestCase):
 
     def test_xml(self):
         # Test 'adminPass' w/o spaces
-        payload = """<adminPass>mypassword</adminPass>"""
+        payload = """<adminPass>TL0EfN33</adminPass>"""
         expected = """<adminPass>***</adminPass>"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'adminPass' with spaces
         payload = """<adminPass>
-                        mypassword
+                        TL0EfN33
                      </adminPass>"""
         expected = """<adminPass>***</adminPass>"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'admin_pass' w/o spaces
-        payload = """<admin_pass>mypassword</admin_pass>"""
+        payload = """<admin_pass>TL0EfN33</admin_pass>"""
         expected = """<admin_pass>***</admin_pass>"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'admin_pass' with spaces
         payload = """<admin_pass>
-                        mypassword
+                        TL0EfN33
                      </admin_pass>"""
         expected = """<admin_pass>***</admin_pass>"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'admin_password' w/o spaces
-        payload = """<admin_password>mypassword</admin_password>"""
+        payload = """<admin_password>TL0EfN33</admin_password>"""
         expected = """<admin_password>***</admin_password>"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'admin_password' with spaces
         payload = """<admin_password>
-                        mypassword
+                        TL0EfN33
                      </admin_password>"""
         expected = """<admin_password>***</admin_password>"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'password' w/o spaces
-        payload = """<password>mypassword</password>"""
+        payload = """<password>TL0EfN33</password>"""
         expected = """<password>***</password>"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'password' with spaces
         payload = """<password>
-                        mypassword
+                        TL0EfN33
                      </password>"""
         expected = """<password>***</password>"""
         self.assertEqual(expected, strutils.mask_password(payload))
 
     def test_xml_attribute(self):
         # Test 'adminPass' w/o spaces
-        payload = """adminPass='mypassword'"""
+        payload = """adminPass='TL0EfN33'"""
         expected = """adminPass='***'"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'adminPass' with spaces
-        payload = """adminPass = 'mypassword'"""
+        payload = """adminPass = 'TL0EfN33'"""
         expected = """adminPass = '***'"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'adminPass' with double quotes
-        payload = """adminPass = "mypassword\""""
+        payload = """adminPass = "TL0EfN33\""""
         expected = """adminPass = "***\""""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'admin_pass' w/o spaces
-        payload = """admin_pass='mypassword'"""
+        payload = """admin_pass='TL0EfN33'"""
         expected = """admin_pass='***'"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'admin_pass' with spaces
-        payload = """admin_pass = 'mypassword'"""
+        payload = """admin_pass = 'TL0EfN33'"""
         expected = """admin_pass = '***'"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'admin_pass' with double quotes
-        payload = """admin_pass = "mypassword\""""
+        payload = """admin_pass = "TL0EfN33\""""
         expected = """admin_pass = "***\""""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'admin_password' w/o spaces
-        payload = """admin_password='mypassword'"""
+        payload = """admin_password='TL0EfN33'"""
         expected = """admin_password='***'"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'admin_password' with spaces
-        payload = """admin_password = 'mypassword'"""
+        payload = """admin_password = 'TL0EfN33'"""
         expected = """admin_password = '***'"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'admin_password' with double quotes
-        payload = """admin_password = "mypassword\""""
+        payload = """admin_password = "TL0EfN33\""""
         expected = """admin_password = "***\""""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'password' w/o spaces
-        payload = """password='mypassword'"""
+        payload = """password='TL0EfN33'"""
         expected = """password='***'"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'password' with spaces
-        payload = """password = 'mypassword'"""
+        payload = """password = 'TL0EfN33'"""
         expected = """password = '***'"""
         self.assertEqual(expected, strutils.mask_password(payload))
         # Test 'password' with double quotes
-        payload = """password = "mypassword\""""
+        payload = """password = "TL0EfN33\""""
         expected = """password = "***\""""
         self.assertEqual(expected, strutils.mask_password(payload))
 
@@ -540,7 +541,7 @@ class MaskPasswordTestCase(test_base.BaseTestCase):
         expected = 'test = "param1" : "value"'
         self.assertEqual(expected, strutils.mask_password(payload))
 
-        payload = """{'adminPass':'mypassword'}"""
+        payload = """{'adminPass':'TL0EfN33'}"""
         payload = six.text_type(payload)
         expected = """{'adminPass':'***'}"""
         self.assertEqual(expected, strutils.mask_password(payload))
@@ -550,35 +551,35 @@ class MaskPasswordTestCase(test_base.BaseTestCase):
         expected = """{'token':'***'}"""
         self.assertEqual(expected, strutils.mask_password(payload))
 
-        payload = ("test = 'node.session.auth.password','-v','mypassword',"
+        payload = ("test = 'node.session.auth.password','-v','TL0EfN33',"
                    "'nomask'")
         expected = ("test = 'node.session.auth.password','-v','***',"
                     "'nomask'")
         self.assertEqual(expected, strutils.mask_password(payload))
 
         payload = ("test = 'node.session.auth.password', '--password', "
-                   "'mypassword', 'nomask'")
+                   "'TL0EfN33', 'nomask'")
         expected = ("test = 'node.session.auth.password', '--password', "
                     "'***', 'nomask'")
         self.assertEqual(expected, strutils.mask_password(payload))
 
         payload = ("test = 'node.session.auth.password', '--password', "
-                   "'mypassword'")
+                   "'TL0EfN33'")
         expected = ("test = 'node.session.auth.password', '--password', "
                     "'***'")
         self.assertEqual(expected, strutils.mask_password(payload))
 
-        payload = "test = node.session.auth.password -v mypassword nomask"
+        payload = "test = node.session.auth.password -v TL0EfN33 nomask"
         expected = "test = node.session.auth.password -v *** nomask"
         self.assertEqual(expected, strutils.mask_password(payload))
 
-        payload = ("test = node.session.auth.password --password mypassword "
+        payload = ("test = node.session.auth.password --password TL0EfN33 "
                    "nomask")
         expected = ("test = node.session.auth.password --password *** "
                     "nomask")
         self.assertEqual(expected, strutils.mask_password(payload))
 
-        payload = ("test = node.session.auth.password --password mypassword")
+        payload = ("test = node.session.auth.password --password TL0EfN33")
         expected = ("test = node.session.auth.password --password ***")
         self.assertEqual(expected, strutils.mask_password(payload))
 
@@ -590,18 +591,18 @@ class MaskPasswordTestCase(test_base.BaseTestCase):
 class MaskDictionaryPasswordTestCase(test_base.BaseTestCase):
 
     def test_dictionary(self):
-        payload = {'password': 'mypassword'}
+        payload = {'password': 'TL0EfN33'}
         expected = {'password': '***'}
         self.assertEqual(expected,
                          strutils.mask_dict_password(payload))
 
-        payload = {'user': 'admin', 'password': 'mypassword'}
+        payload = {'user': 'admin', 'password': 'TL0EfN33'}
         expected = {'user': 'admin', 'password': '***'}
         self.assertEqual(expected,
                          strutils.mask_dict_password(payload))
 
         payload = {'strval': 'somestring',
-                   'dictval': {'user': 'admin', 'password': 'mypassword'}}
+                   'dictval': {'user': 'admin', 'password': 'TL0EfN33'}}
         expected = {'strval': 'somestring',
                     'dictval': {'user': 'admin', 'password': '***'}}
         self.assertEqual(expected,
@@ -609,13 +610,18 @@ class MaskDictionaryPasswordTestCase(test_base.BaseTestCase):
 
         payload = {'strval': '--password abc',
                    'dont_change': 'this is fine',
-                   'dictval': {'user': 'admin', 'password': b'mypassword'}}
+                   'dictval': {'user': 'admin', 'password': b'TL0EfN33'}}
         expected = {'strval': '--password ***',
                     'dont_change': 'this is fine',
                     'dictval': {'user': 'admin', 'password': '***'}}
         self.assertEqual(expected,
                          strutils.mask_dict_password(payload))
 
+        payload = {'ipmi_password': 'KeDrahishvowphyecMornEm0or('}
+        expected = {'ipmi_password': '***'}
+        self.assertEqual(expected,
+                         strutils.mask_dict_password(payload))
+
     def test_do_no_harm(self):
         payload = {}
         expected = {}
@@ -635,6 +641,29 @@ class MaskDictionaryPasswordTestCase(test_base.BaseTestCase):
         self.assertEqual(expected,
                          strutils.mask_dict_password(payload))
 
+    def test_other_non_str_values(self):
+        payload = {'password': 'DK0PK1AK3', 'bool': True,
+                   'dict': {'cat': 'meow', 'password': "*aa38skdjf"},
+                   'float': 0.1, 'int': 123, 'list': [1, 2], 'none': None,
+                   'str': 'foo'}
+        expected = {'password': '***', 'bool': True,
+                    'dict': {'cat': 'meow', 'password': '***'},
+                    'float': 0.1, 'int': 123, 'list': [1, 2], 'none': None,
+                    'str': 'foo'}
+        self.assertEqual(expected,
+                         strutils.mask_dict_password(payload))
+
+    def test_argument_untouched(self):
+        """Make sure that the argument passed in is not modified"""
+        payload = {'password': 'DK0PK1AK3', 'bool': True,
+                   'dict': {'cat': 'meow', 'password': "*aa38skdjf"},
+                   'float': 0.1, 'int': 123, 'list': [1, 2], 'none': None,
+                   'str': 'foo'}
+        pristine = copy.deepcopy(payload)
+        # Send the payload into the function, to see if it gets modified
+        strutils.mask_dict_password(payload)
+        self.assertEqual(pristine, payload)
+
 
 class IsIntLikeTestCase(test_base.BaseTestCase):
     def test_is_int_like_true(self):
@@ -694,3 +723,42 @@ class StringLengthTestCase(test_base.BaseTestCase):
         self.assertRaises(TypeError,
                           strutils.check_string_length,
                           dict(), max_length=255)
+
+
+class SplitPathTestCase(test_base.BaseTestCase):
+    def test_split_path_failed(self):
+        self.assertRaises(ValueError, strutils.split_path, '')
+        self.assertRaises(ValueError, strutils.split_path, '/')
+        self.assertRaises(ValueError, strutils.split_path, '//')
+        self.assertRaises(ValueError, strutils.split_path, '//a')
+        self.assertRaises(ValueError, strutils.split_path, '/a/c')
+        self.assertRaises(ValueError, strutils.split_path, '//c')
+        self.assertRaises(ValueError, strutils.split_path, '/a/c/')
+        self.assertRaises(ValueError, strutils.split_path, '/a//')
+        self.assertRaises(ValueError, strutils.split_path, '/a', 2)
+        self.assertRaises(ValueError, strutils.split_path, '/a', 2, 3)
+        self.assertRaises(ValueError, strutils.split_path, '/a', 2, 3, True)
+        self.assertRaises(ValueError, strutils.split_path, '/a/c/o/r', 3, 3)
+        self.assertRaises(ValueError, strutils.split_path, '/a', 5, 4)
+
+    def test_split_path_success(self):
+        self.assertEqual(strutils.split_path('/a'), ['a'])
+        self.assertEqual(strutils.split_path('/a/'), ['a'])
+        self.assertEqual(strutils.split_path('/a/c', 2), ['a', 'c'])
+        self.assertEqual(strutils.split_path('/a/c/o', 3), ['a', 'c', 'o'])
+        self.assertEqual(strutils.split_path('/a/c/o/r', 3, 3, True),
+                         ['a', 'c', 'o/r'])
+        self.assertEqual(strutils.split_path('/a/c', 2, 3, True),
+                         ['a', 'c', None])
+        self.assertEqual(strutils.split_path('/a/c/', 2), ['a', 'c'])
+        self.assertEqual(strutils.split_path('/a/c/', 2, 3), ['a', 'c', ''])
+
+    def test_split_path_invalid_path(self):
+        try:
+            strutils.split_path('o\nn e', 2)
+        except ValueError as err:
+            self.assertEqual(str(err), 'Invalid path: o%0An%20e')
+        try:
+            strutils.split_path('o\nn e', 2, 3, True)
+        except ValueError as err:
+            self.assertEqual(str(err), 'Invalid path: o%0An%20e')
