@@ -19,14 +19,10 @@ Helpers for comparing version strings.
 .. versionadded:: 1.6
 """
 
-import logging
-
-from oslo_utils._i18n import _
 import pkg_resources
 import six
 
-
-LOG = logging.getLogger(__name__)
+from oslo_utils._i18n import _
 
 
 def is_compatible(requested_version, current_version, same_major=True):
